@@ -1,5 +1,5 @@
 `betadisper` <-
-    function(d, group, type = c("median","centroid"))
+    function(d, group, type = c("median","centroid"), bias.adjust=FALSE)
 {
     ## inline function for spatial medians
     spatialMed <- function(vectors, group, pos) {
@@ -28,8 +28,11 @@
         type <- "median"
     type <- match.arg(type)
     ## checks for groups - need to be a factor for later
-    if(!is.factor(group))
+    if(!is.factor(group)) {
         group <- as.factor(group)
+    } else { ## if already a factor, drop empty levels
+        group <- droplevels(group)
+    }
     n <- attr(d, "Size")
     x <- matrix(0, ncol = n, nrow = n)
     x[row(x) > col(x)] <- d^2
@@ -64,7 +67,8 @@
     ## Remove zero eigenvalues
     eig <- eig[(want <- abs(eig/eig[1]) > TOL)]
     ## scale Eigenvectors
-    vectors <- vectors[, want, drop = FALSE] %*% diag(sqrt(abs(eig)))
+    vectors <- vectors[, want, drop = FALSE] %*% diag(sqrt(abs(eig)),
+                               nrow = length(eig))
     ## store which are the positive eigenvalues
     pos <- eig > 0
     ## group centroids in PCoA space
@@ -86,6 +90,10 @@
 
     ## zij are the distances of each point to its group centroid
     zij <- sqrt(abs(dist.pos - dist.neg))
+    if (bias.adjust) {
+        n.group <- table(group)
+        zij <- zij*sqrt(n.group[group]/(n.group[group]-1))
+    }
     ## add in correct labels
     colnames(vectors) <- names(eig) <- paste("PCoA", seq_along(eig), sep = "")
     if(is.matrix(centroids))
@@ -98,5 +106,6 @@
     class(retval) <- "betadisper"
     attr(retval, "method") <- attr(d, "method")
     attr(retval, "type") <- type
+    attr(retval, "bias.adjust") <- bias.adjust
     retval
 }
