@@ -9,7 +9,7 @@
         stop("display = \"species\" not available for 'capscale'")
     if (is.null(object$CCA)) 
         model <- "CA"
-    if (is.null(object[[model]])) 
+    if (is.null(object[[model]]) || object[[model]]$rank == 0) 
         stop("model ", model, " is not available")
     statistic <- match.arg(statistic)
     cs <- weights(object, display = display)
